import requests
from requests.auth import HTTPBasicAuth
import json

class ComplyAdvantage:

	base_uri = "https://api.complyadvantage.com/v1/"

	def __init__(self, api_key):
		self.auth = HTTPBasicAuth(api_key, 'x')

	def search(self, names):
		response = requests.post(self.base_uri + 'search', data=json.dumps(names), auth=self.auth, verify=False)
		response.raise_for_status()
		return response.json()


from distutils.core import setup
setup(
  name = 'complyadvantage',
  packages = ['complyadvantage'],
  version = '0.1',
  description = 'ComplyAdvantage sanctions API wrapper',
  author = 'ComplyAdvantage',
  author_email = 'jake@complyadvantage.com',
  url = 'https://github.com/complyadvantage/python-sanctions-api', # use the URL to the github repo
  download_url = 'https://github.com/complyadvantage/python-sanctions-api/tarball/0.1', # I'll explain this in a second
  keywords = ['complyadvantage', 'sanctions', 'api'], # arbitrary keywords
  classifiers = [],
  requires=[
        "requests",
  ]
)